<?php namespace Webmors\Catalog\Models;

use Model;

/**
 * Model
 */
class Category extends Model
{
    use \October\Rain\Database\Traits\Validation;
    
    use \October\Rain\Database\Traits\SoftDelete;

    use \October\Rain\Database\Traits\NestedTree;
    
    use \October\Rain\Database\Traits\Sluggable;

    protected $dates = ['deleted_at'];

    protected $slugs = ['slug' => 'name'];

    /**
     * @var string The database table used by the model.
     */
    public $table = 'webmors_catalog_product_category';

    public $hasMany = [
        'products' => ['Webmors\Catalog\Models\Product', 'key' => 'category_id']
    ];
    
    public $implement = ['RainLab.Translate.Behaviors.TranslatableModel'];
        
    public $translatable = ['name']; 
    
    /**
     * @var array Validation rules
     */
    public $rules = [
    ];

    /* Scopes */

    // Get the subcategories of a category
    public function scopeSubcategories($query, $type)
    {
        return $query->where('parent_id', $type)->with('products');
    }
    
    public function childs()
    {
        return $this->hasMany('Webmors\Catalog\Models\Category', 'id', 'parent_id');
    }
}
